@@ -1,3 +1,5 @@
+use std::io::Read;
+
 use colored::*;
 use structopt::StructOpt;
 
@@ -10,11 +12,21 @@ struct Options {
     #[structopt(short = "d", long = "dead")]
     /// Make the cow appear dead
     dead: bool,
+
+    #[structopt(short = "i", long = "stdin")]
+    /// Read the message from STDIN instead of the argument
+    stdin: bool,
 }
 
 fn main() {
     let options = Options::from_args();
-    let message = options.message;
+
+    let mut message = String::new();
+    if options.stdin {
+        std::io::stdin().read_to_string(&mut message).unwrap();
+    } else {
+        message = options.message;
+    }
 
     if message.to_lowercase() == "woof" {
         eprintln!("A cow shouldn't bark like a dog.");
